@@ -1,9 +1,8 @@
 use std::any::Any;
 
-use crate::environment::Environment;
-use crate::function::PROTOTYPES;
-use crate::types::DataType;
-use crate::value::Value;
+use gitql_core::environment::Environment;
+use gitql_core::types::DataType;
+use gitql_core::value::Value;
 
 #[derive(PartialEq)]
 pub enum ExpressionKind {
@@ -17,6 +16,7 @@ pub enum ExpressionKind {
     Arithmetic,
     Comparison,
     Like,
+    Regex,
     Glob,
     Logical,
     Bitwise,
@@ -297,6 +297,25 @@ impl Expression for LikeExpression {
     }
 }
 
+pub struct RegexExpression {
+    pub input: Box<dyn Expression>,
+    pub pattern: Box<dyn Expression>,
+}
+
+impl Expression for RegexExpression {
+    fn kind(&self) -> ExpressionKind {
+        ExpressionKind::Regex
+    }
+
+    fn expr_type(&self, _scope: &Environment) -> DataType {
+        DataType::Boolean
+    }
+
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
+}
+
 pub struct GlobExpression {
     pub input: Box<dyn Expression>,
     pub pattern: Box<dyn Expression>,
@@ -374,7 +393,7 @@ impl Expression for BitwiseExpression {
 pub struct CallExpression {
     pub function_name: String,
     pub arguments: Vec<Box<dyn Expression>>,
-    pub is_aggregation: bool,
+    pub return_type: DataType,
 }
 
 impl Expression for CallExpression {
@@ -383,8 +402,7 @@ impl Expression for CallExpression {
     }
 
     fn expr_type(&self, _scope: &Environment) -> DataType {
-        let prototype = PROTOTYPES.get(&self.function_name.as_str()).unwrap();
-        prototype.return_type.clone()
+        self.return_type.clone()
     }
 
     fn as_any(&self) -> &dyn Any {
