@@ -1,6 +1,3 @@
-use gitql_ast::date_utils::date_time_to_time_stamp;
-use gitql_ast::date_utils::date_to_time_stamp;
-use gitql_ast::environment::Environment;
 use gitql_ast::expression::ArithmeticExpression;
 use gitql_ast::expression::ArithmeticOperator;
 use gitql_ast::expression::AssignmentExpression;
@@ -24,11 +21,12 @@ use gitql_ast::expression::LogicalOperator;
 use gitql_ast::expression::NumberExpression;
 use gitql_ast::expression::PrefixUnary;
 use gitql_ast::expression::PrefixUnaryOperator;
+use gitql_ast::expression::RegexExpression;
 use gitql_ast::expression::StringExpression;
 use gitql_ast::expression::StringValueType;
 use gitql_ast::expression::SymbolExpression;
-use gitql_ast::function::FUNCTIONS;
-use gitql_ast::value::Value;
+use gitql_core::environment::Environment;
+use gitql_core::value::Value;
 
 use regex::Regex;
 use std::string::String;
@@ -108,6 +106,13 @@ pub fn evaluate_expression(
                 .unwrap();
             evaluate_like(env, expr, titles, object)
         }
+        Regex => {
+            let expr = expression
+                .as_any()
+                .downcast_ref::<RegexExpression>()
+                .unwrap();
+            evaluate_regex(env, expr, titles, object)
+        }
         Glob => {
             let expr = expression
                 .as_any()
@@ -180,17 +185,37 @@ fn evaluate_string(expr: &StringExpression) -> Result<Value, String> {
     match expr.value_type {
         StringValueType::Text => Ok(Value::Text(expr.value.to_owned())),
         StringValueType::Time => Ok(Value::Time(expr.value.to_owned())),
-        StringValueType::Date => {
-            let timestamp = date_to_time_stamp(&expr.value);
-            Ok(Value::Date(timestamp))
-        }
-        StringValueType::DateTime => {
-            let timestamp = date_time_to_time_stamp(&expr.value);
-            Ok(Value::DateTime(timestamp))
-        }
+        StringValueType::Date => Ok(string_literal_to_date(&expr.value)),
+        StringValueType::DateTime => Ok(string_literal_to_date_time(&expr.value)),
     }
 }
 
+fn string_literal_to_date(date: &str) -> Value {
+    let date_time = chrono::NaiveDate::parse_from_str(date, "%Y-%m-%d").ok();
+    let timestamp = if let Some(date) = date_time {
+        let zero_time = chrono::NaiveTime::from_hms_opt(0, 0, 0).unwrap();
+        date.and_time(zero_time).and_utc().timestamp()
+    } else {
+        0
+    };
+    Value::Date(timestamp)
+}
+
+fn string_literal_to_date_time(date: &str) -> Value {
+    let date_time_format = if date.contains('.') {
+        "%Y-%m-%d %H:%M:%S%.3f"
+    } else {
+        "%Y-%m-%d %H:%M:%S"
+    };
+
+    let date_time = chrono::NaiveDateTime::parse_from_str(date, date_time_format);
+    if date_time.is_err() {
+        return Value::DateTime(0);
+    }
+
+    Value::DateTime(date_time.ok().unwrap().and_utc().timestamp())
+}
+
 fn evaluate_symbol(
     expr: &SymbolExpression,
     titles: &[String],
@@ -338,6 +363,28 @@ fn evaluate_like(
     Ok(Value::Boolean(regex.is_match(&lhs)))
 }
 
+fn evaluate_regex(
+    env: &mut Environment,
+    expr: &RegexExpression,
+    titles: &[String],
+    object: &Vec<Value>,
+) -> Result<Value, String> {
+    let rhs = evaluate_expression(env, &expr.pattern, titles, object)?.as_text();
+    let pattern = &format!(
+        "^{}$",
+        rhs.to_lowercase().replace('%', ".*").replace('_', ".")
+    );
+    let regex_result = Regex::new(pattern);
+    if regex_result.is_err() {
+        return Err(regex_result.err().unwrap().to_string());
+    }
+    let regex = regex_result.ok().unwrap();
+    let input = evaluate_expression(env, &expr.input, titles, object)?
+        .as_text()
+        .to_lowercase();
+    Ok(Value::Boolean(regex.is_match(&input)))
+}
+
 fn evaluate_glob(
     env: &mut Environment,
     expr: &GlobExpression,
@@ -418,13 +465,12 @@ fn evaluate_call(
     object: &Vec<Value>,
 ) -> Result<Value, String> {
     let function_name = expr.function_name.as_str();
-    let function = FUNCTIONS.get(function_name).unwrap();
-
     let mut arguments = Vec::with_capacity(expr.arguments.len());
     for arg in expr.arguments.iter() {
         arguments.push(evaluate_expression(env, arg, titles, object)?);
     }
 
+    let function = env.std_function(function_name).unwrap();
     Ok(function(&arguments))
 }
 
