@@ -2,11 +2,6 @@ use std::cmp;
 use std::cmp::Ordering;
 use std::collections::HashMap;
 
-use gitql_ast::aggregation::AGGREGATIONS;
-use gitql_ast::environment::Environment;
-use gitql_ast::object::GitQLObject;
-use gitql_ast::object::Group;
-use gitql_ast::object::Row;
 use gitql_ast::statement::AggregateValue;
 use gitql_ast::statement::AggregationsStatement;
 use gitql_ast::statement::GlobalVariableStatement;
@@ -20,7 +15,11 @@ use gitql_ast::statement::SortingOrder;
 use gitql_ast::statement::Statement;
 use gitql_ast::statement::StatementKind::*;
 use gitql_ast::statement::WhereStatement;
-use gitql_ast::value::Value;
+use gitql_core::environment::Environment;
+use gitql_core::object::GitQLObject;
+use gitql_core::object::Group;
+use gitql_core::object::Row;
+use gitql_core::value::Value;
 
 use crate::data_provider::DataProvider;
 use crate::engine_evaluator::evaluate_expression;
@@ -393,7 +392,7 @@ fn execute_aggregation_function_statement(
 
         // Resolve all aggregations functions first
         for aggregation in aggregations_map {
-            if let AggregateValue::Function(function, argument) = aggregation.1 {
+            if let AggregateValue::Function(function, arguments) = aggregation.1 {
                 // Get alias name if exists or column name by default
 
                 let result_column_name = aggregation.0;
@@ -405,10 +404,27 @@ fn execute_aggregation_function_statement(
                     .position(|r| r.eq(&column_name))
                     .unwrap();
 
+                // Evaluate the Arguments to Values
+                let mut group_values: Vec<Vec<Value>> = Vec::with_capacity(group.rows.len());
+                for object in &mut group.rows {
+                    let mut row_values: Vec<Value> = Vec::with_capacity(object.values.len());
+                    for argument in arguments {
+                        let value = evaluate_expression(
+                            env,
+                            argument,
+                            &gitql_object.titles,
+                            &object.values,
+                        )?;
+
+                        row_values.push(value);
+                    }
+
+                    group_values.push(row_values);
+                }
+
                 // Get the target aggregation function
-                let aggregation_function = AGGREGATIONS.get(function.as_str()).unwrap();
-                let result =
-                    &aggregation_function(&argument.to_string(), &gitql_object.titles, group);
+                let aggregation_function = env.aggregation_function(function.as_str()).unwrap();
+                let result = &aggregation_function(group_values);
 
                 // Insert the calculated value in the group objects
                 for object in &mut group.rows {
