@@ -1,5 +1,5 @@
-use gitql_ast::environment::Environment;
-use gitql_ast::value::Value;
+use gitql_core::environment::Environment;
+use gitql_core::value::Value;
 use std::collections::HashMap;
 use std::num::IntErrorKind;
 use std::num::ParseIntError;
@@ -16,13 +16,9 @@ use crate::type_checker::check_function_call_arguments;
 use crate::type_checker::type_check_selected_fields;
 use crate::type_checker::TypeCheckResult;
 
-use gitql_ast::aggregation::AGGREGATIONS;
-use gitql_ast::aggregation::AGGREGATIONS_PROTOS;
 use gitql_ast::expression::*;
-use gitql_ast::function::FUNCTIONS;
-use gitql_ast::function::PROTOTYPES;
 use gitql_ast::statement::*;
-use gitql_ast::types::DataType;
+use gitql_core::types::DataType;
 
 pub fn parse_gql(tokens: Vec<Token>, env: &mut Environment) -> Result<Query, Box<Diagnostic>> {
     let mut position = 0;
@@ -140,21 +136,19 @@ fn parse_show_query(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Query, Box<Diagnostic>> {
-    let len = tokens.len();
-
-    // lets advance
+    // Consume SHOW keyword
     *position += 1;
 
-    if *position >= len || tokens[*position].literal != "tables" {
+    if *position >= tokens.len() || tokens[*position].literal != "tables" {
         return Err(
             Diagnostic::error("Show can not be followed by names other than tables")
+                .add_help("A correct statement will be `SHOW TABLES`")
                 .with_location(get_safe_location(tokens, *position - 1))
                 .as_boxed(),
         );
     }
 
     *position += 1;
-
     Ok(Query::ShowTables)
 }
 
@@ -601,6 +595,10 @@ fn parse_group_by_statement(
     }
 
     let field_name = tokens[*position].literal.to_string();
+    if !context.selected_fields.contains(&field_name) {
+        context.hidden_selections.push(field_name.to_string());
+    }
+
     *position += 1;
 
     if !env.contains(&field_name) {
@@ -892,10 +890,9 @@ fn parse_regex_expression(
             );
         }
 
-        let regex_expr = Box::new(CallExpression {
-            function_name: "regexp_like".to_owned(),
-            arguments: vec![expression, pattern],
-            is_aggregation: false,
+        let regex_expr = Box::new(RegexExpression {
+            input: expression,
+            pattern,
         });
 
         return Ok(if has_not_keyword {
@@ -1721,9 +1718,9 @@ fn parse_function_call_expression(
         let function_name = &symbol_expression.unwrap().value;
 
         // Check if this function is a Standard library functions
-        if FUNCTIONS.contains_key(function_name.as_str()) {
+        if env.is_std_function(function_name.as_str()) {
             let mut arguments = parse_arguments_expressions(context, env, tokens, position)?;
-            let prototype = PROTOTYPES.get(function_name.as_str()).unwrap();
+            let prototype = env.std_signature(function_name.as_str()).unwrap();
             let parameters = &prototype.parameters;
             let mut return_type = prototype.return_type.clone();
             if let DataType::Dynamic(calculate_type) = return_type {
@@ -1739,25 +1736,39 @@ fn parse_function_call_expression(
             )?;
 
             // Register function name with return type
-            env.define(function_name.to_string(), return_type);
+            env.define(function_name.to_string(), return_type.clone());
 
             return Ok(Box::new(CallExpression {
                 function_name: function_name.to_string(),
                 arguments,
-                is_aggregation: false,
+                return_type,
             }));
         }
 
         // Check if this function is an Aggregation functions
-        if AGGREGATIONS.contains_key(function_name.as_str()) {
+        if env.is_aggregation_function(function_name.as_str()) {
+            let aggregations_count_before = context.aggregations.len();
             let mut arguments = parse_arguments_expressions(context, env, tokens, position)?;
-            let prototype = AGGREGATIONS_PROTOS.get(function_name.as_str()).unwrap();
+            let has_aggregations = context.aggregations.len() != aggregations_count_before;
+
+            // Prevent calling aggregation function with aggregation values as argument
+            if has_aggregations {
+                return Err(Diagnostic::error(
+                    "Aggregated values can't as used for aggregation function argument",
+                )
+                .with_location(function_name_location)
+                .as_boxed());
+            }
+
+            let prototype = env.aggregation_signature(function_name.as_str()).unwrap();
+
             let parameters = &prototype.parameters.clone();
             let mut return_type = prototype.return_type.clone();
             if let DataType::Dynamic(calculate_type) = return_type {
                 return_type = calculate_type(parameters);
             }
 
+            // Perform type checking and implicit casting if needed for function arguments
             check_function_call_arguments(
                 env,
                 &mut arguments,
@@ -1766,18 +1777,7 @@ fn parse_function_call_expression(
                 function_name_location,
             )?;
 
-            let argument_result = get_expression_name(&arguments[0]);
-            if argument_result.is_err() {
-                return Err(Diagnostic::error("Invalid Aggregation function argument")
-                    .add_help("Try to use field name as Aggregation function argument")
-                    .add_note("Aggregation function accept field name as argument")
-                    .with_location(function_name_location)
-                    .as_boxed());
-            }
-
-            let argument = argument_result.ok().unwrap();
             let column_name = context.generate_column_name();
-
             context.hidden_selections.push(column_name.to_string());
 
             // Register aggregation generated name with return type
@@ -1785,9 +1785,10 @@ fn parse_function_call_expression(
 
             context.aggregations.insert(
                 column_name.clone(),
-                AggregateValue::Function(function_name.to_string(), argument),
+                AggregateValue::Function(function_name.to_string(), arguments),
             );
 
+            // Return a Symbol that reference to the aggregation function generated name
             return Ok(Box::new(SymbolExpression { value: column_name }));
         }
 
