@@ -1,14 +1,14 @@
-use gitql_ast::date_utils::is_valid_date_format;
-use gitql_ast::date_utils::is_valid_datetime_format;
-use gitql_ast::date_utils::is_valid_time_format;
-use gitql_ast::environment::Environment;
 use gitql_ast::expression::Expression;
 use gitql_ast::expression::ExpressionKind;
 use gitql_ast::expression::StringExpression;
 use gitql_ast::expression::StringValueType;
-use gitql_ast::types::DataType;
+use gitql_core::environment::Environment;
+use gitql_core::types::DataType;
 
 use crate::diagnostic::Diagnostic;
+use crate::format_checker::is_valid_date_format;
+use crate::format_checker::is_valid_datetime_format;
+use crate::format_checker::is_valid_time_format;
 use crate::tokenizer::Location;
 
 /// The return result after performing types checking with implicit casting option
@@ -300,7 +300,7 @@ pub fn check_all_values_are_same_type(
 /// Check That function call arguments types are matches the parameter types
 /// Return a Diagnostic Error if anything is wrong
 pub fn check_function_call_arguments(
-    env: &mut Environment,
+    env: &Environment,
     arguments: &mut [Box<dyn Expression>],
     parameters: &[DataType],
     function_name: String,
@@ -350,6 +350,19 @@ pub fn check_function_call_arguments(
     for index in 0..min_arguments_count {
         let parameter_type = parameters.get(index).unwrap();
         let argument = arguments.get(index).unwrap();
+
+        // Catch undefined arguments
+        if argument.expr_type(env).is_undefined() {
+            return Err(Diagnostic::error(&format!(
+                "Function `{}` argument number {} has Undefined type",
+                function_name, index,
+            ))
+            .add_help("Make sure you used a correct field name")
+            .add_help("Check column names for each table from docs website")
+            .with_location(location)
+            .as_boxed());
+        }
+
         match is_expression_type_equals(env, argument, parameter_type) {
             TypeCheckResult::Equals => {}
             TypeCheckResult::RightSideCasted(new_expr) => {
@@ -379,6 +392,19 @@ pub fn check_function_call_arguments(
 
         let parameter_type = parameters.get(index).unwrap();
         let argument = arguments.get(index).unwrap();
+
+        // Catch undefined arguments
+        if argument.expr_type(env).is_undefined() {
+            return Err(Diagnostic::error(&format!(
+                "Function `{}` argument number {} has Undefined type",
+                function_name, index,
+            ))
+            .add_help("Make sure you used a correct field name")
+            .add_help("Check column names for each table from docs website")
+            .with_location(location)
+            .as_boxed());
+        }
+
         match is_expression_type_equals(env, argument, parameter_type) {
             TypeCheckResult::Equals => {}
             TypeCheckResult::RightSideCasted(new_expr) => {
@@ -404,6 +430,19 @@ pub fn check_function_call_arguments(
         let varargs_type = parameters.last().unwrap();
         for index in last_optional_param_index..arguments_count {
             let argument = arguments.get(index).unwrap();
+
+            // Catch undefined arguments
+            if argument.expr_type(env).is_undefined() {
+                return Err(Diagnostic::error(&format!(
+                    "Function `{}` argument number {} has Undefined type",
+                    function_name, index,
+                ))
+                .add_help("Make sure you used a correct field name")
+                .add_help("Check column names for each table from docs website")
+                .with_location(location)
+                .as_boxed());
+            }
+
             match is_expression_type_equals(env, argument, varargs_type) {
                 TypeCheckResult::Equals => {}
                 TypeCheckResult::RightSideCasted(new_expr) => {
